export class Image {
    constructor(data) {
        this.packages = [];
        this.repositories = [];
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.name = _data['Name'];
            if (Array.isArray(_data['Packages'])) {
                this.packages = [];
                for (const item of _data['Packages'])
                    this.packages.push(PackageSpecifier.fromJS(item));
            }
            if (Array.isArray(_data['Repositories'])) {
                this.repositories = [];
                for (const item of _data['Repositories'])
                    this.repositories.push(item);
            }
            this.id = _data['Id'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new Image();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Name'] = this.name;
        if (Array.isArray(this.packages)) {
            data['Packages'] = [];
            for (const item of this.packages)
                data['Packages'].push(item.toJSON());
        }
        if (Array.isArray(this.repositories)) {
            data['Repositories'] = [];
            for (const item of this.repositories)
                data['Repositories'].push(item);
        }
        data['Id'] = this.id;
        return data;
    }
}
export class PackageSpecifier {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.name = _data['Name'];
            this.version = _data['Version'];
            this.architecture = _data['Architecture'];
            this.oS = _data['OS'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new PackageSpecifier();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Name'] = this.name;
        data['Version'] = this.version;
        data['Architecture'] = this.architecture;
        data['OS'] = this.oS;
        return data;
    }
}
export class ErrorResponse {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.type = _data['Type'];
            this.message = _data['Message'];
            this.parameter = _data['Parameter'];
            this.source = _data['Source'];
            this.stackTrace = _data['StackTrace'];
            this.inner = _data['Inner'] ? ErrorResponse.fromJS(_data['Inner']) : undefined;
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ErrorResponse();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Type'] = this.type;
        data['Message'] = this.message;
        data['Parameter'] = this.parameter;
        data['Source'] = this.source;
        data['StackTrace'] = this.stackTrace;
        data['Inner'] = this.inner ? this.inner.toJSON() : undefined;
        return data;
    }
}
export class NoResponderError extends ErrorResponse {
    constructor() {
        super({ message: 'No responders.' });
    }
    static fromJS() {
        return new NoResponderError();
    }
}
export class ImageResolveErrorResponse extends ErrorResponse {
    constructor(data) {
        super(data);
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.dotGraph = _data['DotGraph'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ImageResolveErrorResponse();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['DotGraph'] = this.dotGraph;
        super.toJSON(data);
        return data;
    }
}
export class Session {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.subject = _data['Subject'];
            this.id = _data['Id'];
            this.imageId = _data['ImageId'];
            this.executionState = _data['ExecutionState'];
            this.testPlanRunId = _data['TestPlanRunId'];
            this.startedBy = _data['StartedBy'];
            this.metadata = _data['Metadata'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new Session();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Subject'] = this.subject;
        data['Id'] = this.id;
        data['ImageId'] = this.imageId;
        data['ExecutionState'] = this.executionState;
        data['TestPlanRunId'] = this.testPlanRunId;
        data['StartedBy'] = this.startedBy;
        data['Metadata'] = this.metadata;
        return data;
    }
}
export class Links {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.editor = _data['Editor'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new Links();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Editor'] = this.editor;
        return data;
    }
}
export class ComponentSettingsBase {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
        this._discriminator = 'ComponentSettingsBase';
    }
    init(_data) {
        if (_data) {
            this.name = _data['Name'];
            this.groupName = _data['GroupName'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        if (data['ComponentSettingsType'] === 'ComponentSettingsIdentifier') {
            const result = new ComponentSettingsIdentifier();
            result.init(data);
            return result;
        }
        if (data['ComponentSettingsType'] === 'ComponentSettingsList') {
            const result = new ComponentSettingsList();
            result.init(data);
            return result;
        }
        if (data['ComponentSettingsType'] === 'ComponentSettings') {
            const result = new ComponentSettings();
            result.init(data);
            return result;
        }
        throw new Error("The abstract class 'ComponentSettingsBase' cannot be instantiated.");
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['ComponentSettingsType'] = this._discriminator;
        data['Name'] = this.name;
        data['GroupName'] = this.groupName;
        return data;
    }
}
export class ComponentSettingsIdentifier extends ComponentSettingsBase {
    constructor(data) {
        super(data);
        this._discriminator = 'ComponentSettingsIdentifier';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ComponentSettingsIdentifier();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
/** The supported layout modes. */
export var DisplayMode;
(function (DisplayMode) {
    DisplayMode["MasterDetail"] = "MasterDetail";
    DisplayMode["DataGrid"] = "DataGrid";
})(DisplayMode || (DisplayMode = {}));
export class ComponentSettingsList extends ComponentSettingsBase {
    constructor(data) {
        super(data);
        this._discriminator = 'ComponentSettingsList';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            if (Array.isArray(_data['Items'])) {
                this.items = [];
                for (const item of _data['Items'])
                    this.items.push(ComponentSettingsListItem.fromJS(item));
            }
            this.displayMode = _data['DisplayMode'];
            this.itemType = _data['ItemType'];
            this.itemTypeDisplayName = _data['ItemTypeDisplayName'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ComponentSettingsList();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.items)) {
            data['Items'] = [];
            for (const item of this.items)
                data['Items'].push(item.toJSON());
        }
        data['DisplayMode'] = this.displayMode;
        data['ItemType'] = this.itemType;
        data['ItemTypeDisplayName'] = this.itemTypeDisplayName;
        super.toJSON(data);
        return data;
    }
}
export class AnnotatedObject {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.visualStatus = _data['VisualStatus'] ? VisualStatus.fromJS(_data['VisualStatus']) : undefined;
            this.valueType = _data['ValueType'];
            this.display = _data['Display'] ? DisplayAttribute.fromJS(_data['Display']) : undefined;
            this.metaData = _data['MetaData'] ? MetaData.fromJS(_data['MetaData']) : undefined;
            this.externalParameter = _data['ExternalParameter'] ? ExternalParameter.fromJS(_data['ExternalParameter']) : undefined;
            this.unitAttribute = _data['UnitAttribute'] ? UnitAttribute.fromJS(_data['UnitAttribute']) : undefined;
        }
    }
    static fromJS(data) {
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
        data = typeof data === 'object' ? data : {};
        throw new Error("The abstract class 'AnnotatedObject' cannot be instantiated.");
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['VisualStatus'] = this.visualStatus ? this.visualStatus.toJSON() : undefined;
        data['ValueType'] = this.valueType;
        data['Display'] = this.display ? this.display.toJSON() : undefined;
        data['MetaData'] = this.metaData ? this.metaData.toJSON() : undefined;
        data['ExternalParameter'] = this.externalParameter ? this.externalParameter.toJSON() : undefined;
        data['UnitAttribute'] = this.unitAttribute ? this.unitAttribute.toJSON() : undefined;
        return data;
    }
}
export class ComponentSettingsListItem extends AnnotatedObject {
    constructor(data) {
        super(data);
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            if (Array.isArray(_data['Settings'])) {
                this.settings = [];
                for (const item of _data['Settings'])
                    this.settings.push(Setting.fromJS(item));
            }
            this.name = _data['Name'];
            this.enabledResource = _data['EnabledResource'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ComponentSettingsListItem();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.settings)) {
            data['Settings'] = [];
            for (const item of this.settings)
                data['Settings'].push(item.toJSON());
        }
        data['Name'] = this.name;
        data['EnabledResource'] = this.enabledResource;
        super.toJSON(data);
        return data;
    }
}
export class Setting extends AnnotatedObject {
    constructor(data) {
        super(data);
        this._discriminator = 'Setting';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            if (Array.isArray(_data['Errors'])) {
                this.errors = [];
                for (const item of _data['Errors'])
                    this.errors.push(item);
            }
            this.layout = _data['Layout'] ? Layout.fromJS(_data['Layout']) : undefined;
            this.columnDisplayName = _data['ColumnDisplayName'] ? ColumnDisplayName.fromJS(_data['ColumnDisplayName']) : undefined;
            this.valueDescription = _data['ValueDescription'];
            this.propertyName = _data['PropertyName'];
            this.submit = _data['Submit'];
            if (Array.isArray(_data['Icons'])) {
                this.icons = [];
                for (const item of _data['Icons'])
                    this.icons.push(Icon.fromJS(item));
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        if (data['ControlType'] === 'ButtonControl') {
            const result = new ButtonControl();
            result.init(data);
            return result;
        }
        if (data['ControlType'] === 'ButtonsControl') {
            const result = new ButtonsControl();
            result.init(data);
            return result;
        }
        if (data['ControlType'] === 'CheckBoxControl') {
            const result = new CheckBoxControl();
            result.init(data);
            return result;
        }
        if (data['ControlType'] === 'DataGridReferenceControl') {
            const result = new DataGridReferenceControl();
            result.init(data);
            return result;
        }
        if (data['ControlType'] === 'DataGridControl') {
            const result = new DataGridControl();
            result.init(data);
            return result;
        }
        if (data['ControlType'] === 'TextBoxControl') {
            const result = new TextBoxControl();
            result.init(data);
            return result;
        }
        if (data['ControlType'] === 'ComboBoxControl') {
            const result = new ComboBoxControl();
            result.init(data);
            return result;
        }
        if (data['ControlType'] === 'FilePathControl') {
            const result = new FilePathControl();
            result.init(data);
            return result;
        }
        if (data['ControlType'] === 'DirectoryPathControl') {
            const result = new DirectoryPathControl();
            result.init(data);
            return result;
        }
        if (data['ControlType'] === 'EnabledControl') {
            const result = new EnabledControl();
            result.init(data);
            return result;
        }
        if (data['ControlType'] === 'DropdownControl') {
            const result = new DropdownControl();
            result.init(data);
            return result;
        }
        if (data['ControlType'] === 'MultiSelectControl') {
            const result = new MultiSelectControl();
            result.init(data);
            return result;
        }
        if (data['ControlType'] === 'PasswordControl') {
            const result = new PasswordControl();
            result.init(data);
            return result;
        }
        if (data['ControlType'] === 'PictureControl') {
            const result = new PictureControl();
            result.init(data);
            return result;
        }
        if (data['ControlType'] === 'PluginTypeSelectorControl') {
            const result = new PluginTypeSelectorControl();
            result.init(data);
            return result;
        }
        const result = new Setting();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['ControlType'] = this._discriminator;
        if (Array.isArray(this.errors)) {
            data['Errors'] = [];
            for (const item of this.errors)
                data['Errors'].push(item);
        }
        data['Layout'] = this.layout ? this.layout.toJSON() : undefined;
        data['ColumnDisplayName'] = this.columnDisplayName ? this.columnDisplayName.toJSON() : undefined;
        data['ValueDescription'] = this.valueDescription;
        data['PropertyName'] = this.propertyName;
        data['Submit'] = this.submit;
        if (Array.isArray(this.icons)) {
            data['Icons'] = [];
            for (const item of this.icons)
                data['Icons'].push(item.toJSON());
        }
        super.toJSON(data);
        return data;
    }
}
export class Layout {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.mode = _data['Mode'];
            this.rowHeight = _data['RowHeight'];
            this.maxRowHeight = _data['MaxRowHeight'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new Layout();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Mode'] = this.mode;
        data['RowHeight'] = this.rowHeight;
        data['MaxRowHeight'] = this.maxRowHeight;
        return data;
    }
}
/** The supported layout modes. */
export var LayoutMode;
(function (LayoutMode) {
    LayoutMode["Normal"] = "Normal";
    LayoutMode["FullRow"] = "FullRow";
    LayoutMode["FloatBottom"] = "FloatBottom";
})(LayoutMode || (LayoutMode = {}));
export class ColumnDisplayName {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.columnName = _data['ColumnName'];
            this.order = _data['Order'];
            this.isReadOnly = _data['IsReadOnly'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ColumnDisplayName();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['ColumnName'] = this.columnName;
        data['Order'] = this.order;
        data['IsReadOnly'] = this.isReadOnly;
        return data;
    }
}
export class Icon {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.iconName = _data['IconName'];
            this.invoke = _data['Invoke'];
            this.stepReference = _data['StepReference'];
            this.propertyReference = _data['PropertyReference'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new Icon();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['IconName'] = this.iconName;
        data['Invoke'] = this.invoke;
        data['StepReference'] = this.stepReference;
        data['PropertyReference'] = this.propertyReference;
        return data;
    }
}
export class UnitAttribute {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.unit = _data['Unit'];
            this.preScaling = _data['PreScaling'];
            this.stringFormat = _data['StringFormat'];
            this.useRanges = _data['UseRanges'];
            this.useEngineeringPrefix = _data['UseEngineeringPrefix'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new UnitAttribute();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Unit'] = this.unit;
        data['PreScaling'] = this.preScaling;
        data['StringFormat'] = this.stringFormat;
        data['UseRanges'] = this.useRanges;
        data['UseEngineeringPrefix'] = this.useEngineeringPrefix;
        return data;
    }
}
export class VisualStatus {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.isReadOnly = _data['IsReadOnly'];
            this.isVisible = _data['IsVisible'];
            this.isEnabled = _data['IsEnabled'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new VisualStatus();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['IsReadOnly'] = this.isReadOnly;
        data['IsVisible'] = this.isVisible;
        data['IsEnabled'] = this.isEnabled;
        return data;
    }
}
export class DisplayAttribute {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.description = _data['Description'];
            if (Array.isArray(_data['Group'])) {
                this.group = [];
                for (const item of _data['Group'])
                    this.group.push(item);
            }
            this.name = _data['Name'];
            this.order = _data['Order'];
            this.collapsed = _data['Collapsed'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new DisplayAttribute();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Description'] = this.description;
        if (Array.isArray(this.group)) {
            data['Group'] = [];
            for (const item of this.group)
                data['Group'].push(item);
        }
        data['Name'] = this.name;
        data['Order'] = this.order;
        data['Collapsed'] = this.collapsed;
        return data;
    }
}
export class MetaData {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.name = _data['Name'];
            this.macroName = _data['MacroName'];
            this.group = _data['Group'];
            this.frozen = _data['Frozen'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new MetaData();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Name'] = this.name;
        data['MacroName'] = this.macroName;
        data['Group'] = this.group;
        data['Frozen'] = this.frozen;
        return data;
    }
}
export class ExternalParameter {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.name = _data['Name'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ExternalParameter();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Name'] = this.name;
        return data;
    }
}
export class ButtonControl extends Setting {
    constructor(data) {
        super(data);
        this._discriminator = 'ButtonControl';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.invokeMethod = _data['InvokeMethod'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ButtonControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['InvokeMethod'] = this.invokeMethod;
        super.toJSON(data);
        return data;
    }
}
export class ButtonsControl extends Setting {
    constructor(data) {
        super(data);
        this._discriminator = 'ButtonsControl';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            if (Array.isArray(_data['AvailableValues'])) {
                this.availableValues = [];
                for (const item of _data['AvailableValues'])
                    this.availableValues.push(AvailableValue.fromJS(item));
            }
            this.selectedIndex = _data['SelectedIndex'];
            this.invokeMethod = _data['InvokeMethod'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ButtonsControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.availableValues)) {
            data['AvailableValues'] = [];
            for (const item of this.availableValues)
                data['AvailableValues'].push(item.toJSON());
        }
        data['SelectedIndex'] = this.selectedIndex;
        data['InvokeMethod'] = this.invokeMethod;
        super.toJSON(data);
        return data;
    }
}
export class AvailableValue {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.name = _data['Name'];
            this.description = _data['Description'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new AvailableValue();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Name'] = this.name;
        data['Description'] = this.description;
        return data;
    }
}
export class CheckBoxControl extends Setting {
    constructor(data) {
        super(data);
        this._discriminator = 'CheckBoxControl';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.boolValue = _data['BoolValue'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new CheckBoxControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['BoolValue'] = this.boolValue;
        super.toJSON(data);
        return data;
    }
}
export class DataGridReferenceControl extends Setting {
    constructor(data) {
        super(data);
        this._discriminator = 'DataGridReferenceControl';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new DataGridReferenceControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class DataGridControl extends Setting {
    constructor(data) {
        super(data);
        this._discriminator = 'DataGridControl';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            if (Array.isArray(_data['Items'])) {
                this.items = [];
                for (const item of _data['Items'])
                    this.items.push(item);
            }
            this.fixedSize = _data['FixedSize'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new DataGridControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.items)) {
            data['Items'] = [];
            for (const item of this.items)
                data['Items'].push(item);
        }
        data['FixedSize'] = this.fixedSize;
        super.toJSON(data);
        return data;
    }
}
export class TextBoxControl extends Setting {
    constructor(data) {
        super(data);
        this._discriminator = 'TextBoxControl';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.stringValue = _data['StringValue'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        if (data['ControlType'] === 'ComboBoxControl') {
            const result = new ComboBoxControl();
            result.init(data);
            return result;
        }
        const result = new TextBoxControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['StringValue'] = this.stringValue;
        super.toJSON(data);
        return data;
    }
}
export class ComboBoxControl extends TextBoxControl {
    constructor(data) {
        super(data);
        this._discriminator = 'ComboBoxControl';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            if (Array.isArray(_data['SuggestedValues'])) {
                this.suggestedValues = [];
                for (const item of _data['SuggestedValues'])
                    this.suggestedValues.push(item);
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ComboBoxControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.suggestedValues)) {
            data['SuggestedValues'] = [];
            for (const item of this.suggestedValues)
                data['SuggestedValues'].push(item);
        }
        super.toJSON(data);
        return data;
    }
}
export class FilePathControl extends Setting {
    constructor(data) {
        super(data);
        this._discriminator = 'FilePathControl';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.stringValue = _data['StringValue'];
            this.fileExtension = _data['FileExtension'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new FilePathControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['StringValue'] = this.stringValue;
        data['FileExtension'] = this.fileExtension;
        super.toJSON(data);
        return data;
    }
}
export class DirectoryPathControl extends Setting {
    constructor(data) {
        super(data);
        this._discriminator = 'DirectoryPathControl';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.stringValue = _data['StringValue'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new DirectoryPathControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['StringValue'] = this.stringValue;
        super.toJSON(data);
        return data;
    }
}
export class EnabledControl extends Setting {
    constructor(data) {
        super(data);
        this._discriminator = 'EnabledControl';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.isEnabled = _data['IsEnabled'];
            this.value = _data['Value'] ? Setting.fromJS(_data['Value']) : undefined;
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new EnabledControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['IsEnabled'] = this.isEnabled;
        data['Value'] = this.value ? this.value.toJSON() : undefined;
        super.toJSON(data);
        return data;
    }
}
export class DropdownControl extends Setting {
    constructor(data) {
        super(data);
        this._discriminator = 'DropdownControl';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            if (Array.isArray(_data['AvailableValues'])) {
                this.availableValues = [];
                for (const item of _data['AvailableValues'])
                    this.availableValues.push(AvailableValue.fromJS(item));
            }
            this.selectedIndex = _data['SelectedIndex'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new DropdownControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.availableValues)) {
            data['AvailableValues'] = [];
            for (const item of this.availableValues)
                data['AvailableValues'].push(item.toJSON());
        }
        data['SelectedIndex'] = this.selectedIndex;
        super.toJSON(data);
        return data;
    }
}
export class MultiSelectControl extends Setting {
    constructor(data) {
        super(data);
        this._discriminator = 'MultiSelectControl';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            if (Array.isArray(_data['AvailableValues'])) {
                this.availableValues = [];
                for (const item of _data['AvailableValues'])
                    this.availableValues.push(AvailableValue.fromJS(item));
            }
            if (Array.isArray(_data['SelectedIndex'])) {
                this.selectedIndex = [];
                for (const item of _data['SelectedIndex'])
                    this.selectedIndex.push(item);
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new MultiSelectControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.availableValues)) {
            data['AvailableValues'] = [];
            for (const item of this.availableValues)
                data['AvailableValues'].push(item.toJSON());
        }
        if (Array.isArray(this.selectedIndex)) {
            data['SelectedIndex'] = [];
            for (const item of this.selectedIndex)
                data['SelectedIndex'].push(item);
        }
        super.toJSON(data);
        return data;
    }
}
export class PasswordControl extends Setting {
    constructor(data) {
        super(data);
        this._discriminator = 'PasswordControl';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.password = _data['Password'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new PasswordControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Password'] = this.password;
        super.toJSON(data);
        return data;
    }
}
export class PictureControl extends Setting {
    constructor(data) {
        super(data);
        this._discriminator = 'PictureControl';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.description = _data['Description'];
            this.mimeType = _data['MimeType'];
            this.resource = _data['Resource'] ? Resource.fromJS(_data['Resource']) : undefined;
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new PictureControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Description'] = this.description;
        data['MimeType'] = this.mimeType;
        data['Resource'] = this.resource ? this.resource.toJSON() : undefined;
        super.toJSON(data);
        return data;
    }
}
export class PluginTypeSelectorControl extends Setting {
    constructor(data) {
        super(data);
        this.availableValues = [];
        this._discriminator = 'PluginTypeSelectorControl';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            if (Array.isArray(_data['AvailableValues'])) {
                this.availableValues = [];
                for (const item of _data['AvailableValues'])
                    this.availableValues.push(AvailableValue.fromJS(item));
            }
            this.selectedIndex = _data['SelectedIndex'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new PluginTypeSelectorControl();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.availableValues)) {
            data['AvailableValues'] = [];
            for (const item of this.availableValues)
                data['AvailableValues'].push(item.toJSON());
        }
        data['SelectedIndex'] = this.selectedIndex;
        super.toJSON(data);
        return data;
    }
}
export class Resource {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.source = _data['Source'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new Resource();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Source'] = this.source;
        return data;
    }
}
export class FileDescriptor {
    constructor(fileSize, chunkSize) {
        var _a;
        if (chunkSize === 0) {
            throw Error('chunkSize cannot set to 0');
        }
        this.fileSize = fileSize;
        this.chunkSize = chunkSize;
        this.numberOfChunks = Math.floor((((_a = this.fileSize) !== null && _a !== void 0 ? _a : 0) + this.chunkSize - 1) / this.chunkSize);
    }
    init(_data) {
        if (_data) {
            this.numberOfChunks = _data['NumberOfChunks'];
            this.fileSize = _data['FileSize'];
            this.chunkSize = _data['ChunkSize'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new FileDescriptor(0, 512000);
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['NumberOfChunks'] = this.numberOfChunks;
        data['FileSize'] = this.fileSize;
        data['ChunkSize'] = this.chunkSize;
        return data;
    }
}
export class ComponentSettings extends ComponentSettingsBase {
    constructor(data) {
        super(data);
        this._discriminator = 'ComponentSettings';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            if (Array.isArray(_data['Settings'])) {
                this.settings = [];
                for (const item of _data['Settings'])
                    this.settings.push(Setting.fromJS(item));
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ComponentSettings();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.settings)) {
            data['Settings'] = [];
            for (const item of this.settings)
                data['Settings'].push(item.toJSON());
        }
        super.toJSON(data);
        return data;
    }
}
export class ListItemType {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.typeName = _data['TypeName'];
            this.typeDisplay = _data['TypeDisplay'] ? DisplayAttribute.fromJS(_data['TypeDisplay']) : undefined;
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ListItemType();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['TypeName'] = this.typeName;
        data['TypeDisplay'] = this.typeDisplay ? this.typeDisplay.toJSON() : undefined;
        return data;
    }
}
export class ProfileGroup {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            if (Array.isArray(_data['Profiles'])) {
                this.profiles = [];
                for (const item of _data['Profiles'])
                    this.profiles.push(item);
            }
            this.currentProfile = _data['CurrentProfile'];
            this.groupName = _data['GroupName'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ProfileGroup();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.profiles)) {
            data['Profiles'] = [];
            for (const item of this.profiles)
                data['Profiles'].push(item);
        }
        data['CurrentProfile'] = this.currentProfile;
        data['GroupName'] = this.groupName;
        return data;
    }
}
export class RepositoryPackageReference {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.name = _data['Name'];
            this.version = _data['Version'];
            this.repository = _data['Repository'];
            this.path = _data['Path'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new RepositoryPackageReference();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Name'] = this.name;
        data['Version'] = this.version;
        data['Repository'] = this.repository;
        data['Path'] = this.path;
        return data;
    }
}
export class RepositoryPackageDefinition extends RepositoryPackageReference {
    constructor(data) {
        super(data);
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            if (Array.isArray(_data['Tags'])) {
                this.tags = [];
                for (const item of _data['Tags'])
                    this.tags.push(item);
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new RepositoryPackageDefinition();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.tags)) {
            data['Tags'] = [];
            for (const item of this.tags)
                data['Tags'].push(item);
        }
        super.toJSON(data);
        return data;
    }
}
export class RepositorySettingsPackageDefinition extends RepositoryPackageDefinition {
    constructor(data) {
        super(data);
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new RepositorySettingsPackageDefinition();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class SettingsTapPackage {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.name = _data['Name'];
            this.version = _data['Version'];
            this.tags = _data['Tags'];
            this.group = _data['Group'];
            this.owner = _data['Owner'];
            this.infoLink = _data['InfoLink'];
            this.description = _data['Description'];
            if (Array.isArray(_data['Files'])) {
                this.files = [];
                for (const item of _data['Files'])
                    this.files.push(item);
            }
            if (Array.isArray(_data['SettingsTypes'])) {
                this.settingsTypes = [];
                for (const item of _data['SettingsTypes'])
                    this.settingsTypes.push(item);
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new SettingsTapPackage();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Name'] = this.name;
        data['Version'] = this.version;
        data['Tags'] = this.tags;
        data['Group'] = this.group;
        data['Owner'] = this.owner;
        data['InfoLink'] = this.infoLink;
        data['Description'] = this.description;
        if (Array.isArray(this.files)) {
            data['Files'] = [];
            for (const item of this.files)
                data['Files'].push(item);
        }
        if (Array.isArray(this.settingsTypes)) {
            data['SettingsTypes'] = [];
            for (const item of this.settingsTypes)
                data['SettingsTypes'].push(item);
        }
        return data;
    }
}
export class SessionEventArgs {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
        this._discriminator = 'SessionEventArgs';
    }
    init(_data) {
        if (_data) {
            this.sessionId = _data['SessionId'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        if (data['SessionEventType'] === 'SessionStartInitiated') {
            const result = new SessionStartInitiated();
            result.init(data);
            return result;
        }
        if (data['SessionEventType'] === 'SessionStarted') {
            const result = new SessionStarted();
            result.init(data);
            return result;
        }
        if (data['SessionEventType'] === 'SessionStartFailed') {
            const result = new SessionStartFailed();
            result.init(data);
            return result;
        }
        if (data['SessionEventType'] === 'SessionShutdownInitiated') {
            const result = new SessionShutdownInitiated();
            result.init(data);
            return result;
        }
        if (data['SessionEventType'] === 'SessionShutdown') {
            const result = new SessionShutdown();
            result.init(data);
            return result;
        }
        if (data['SessionEventType'] === 'SessionShutdownFailed') {
            const result = new SessionShutdownFailed();
            result.init(data);
            return result;
        }
        if (data['SessionEventType'] === 'SessionInactivityLimitHit') {
            const result = new SessionInactivityLimitHit();
            result.init(data);
            return result;
        }
        const result = new SessionEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['SessionEventType'] = this._discriminator;
        data['SessionId'] = this.sessionId;
        return data;
    }
}
export class SessionStartInitiated extends SessionEventArgs {
    constructor(data) {
        super(data);
        this._discriminator = 'SessionStartInitiated';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new SessionStartInitiated();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class SessionStarted extends SessionEventArgs {
    constructor(data) {
        super(data);
        this._discriminator = 'SessionStarted';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.session = _data['Session'] ? Session.fromJS(_data['Session']) : undefined;
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new SessionStarted();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Session'] = this.session ? this.session.toJSON() : undefined;
        super.toJSON(data);
        return data;
    }
}
export class SessionStartFailed extends SessionEventArgs {
    constructor(data) {
        super(data);
        this._discriminator = 'SessionStartFailed';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.reason = _data['Reason'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new SessionStartFailed();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Reason'] = this.reason;
        super.toJSON(data);
        return data;
    }
}
export class SessionShutdownInitiated extends SessionEventArgs {
    constructor(data) {
        super(data);
        this._discriminator = 'SessionShutdownInitiated';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new SessionShutdownInitiated();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class SessionShutdown extends SessionEventArgs {
    constructor(data) {
        super(data);
        this._discriminator = 'SessionShutdown';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new SessionShutdown();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class SessionShutdownFailed extends SessionEventArgs {
    constructor(data) {
        super(data);
        this._discriminator = 'SessionShutdownFailed';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.reason = _data['Reason'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new SessionShutdownFailed();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Reason'] = this.reason;
        super.toJSON(data);
        return data;
    }
}
export class SessionInactivityLimitHit extends SessionEventArgs {
    constructor(data) {
        super(data);
        this._discriminator = 'SessionInactivityLimitHit';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new SessionInactivityLimitHit();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class ImageEventArgs {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
        this._discriminator = 'ImageEventArgs';
    }
    init(_data) {
        if (_data) {
            this.imageId = _data['ImageId'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        if (data['ImageEventType'] === 'ImageCreating') {
            const result = new ImageCreating();
            result.init(data);
            return result;
        }
        if (data['ImageEventType'] === 'ImageCreated') {
            const result = new ImageCreated();
            result.init(data);
            return result;
        }
        if (data['ImageEventType'] === 'ImageCreationFailed') {
            const result = new ImageCreationFailed();
            result.init(data);
            return result;
        }
        const result = new ImageEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['ImageEventType'] = this._discriminator;
        data['ImageId'] = this.imageId;
        return data;
    }
}
export class ImageCreating extends ImageEventArgs {
    constructor(data) {
        super(data);
        this._discriminator = 'ImageCreating';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ImageCreating();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class ImageCreated extends ImageEventArgs {
    constructor(data) {
        super(data);
        this._discriminator = 'ImageCreated';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.image = _data['Image'] ? Image.fromJS(_data['Image']) : undefined;
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ImageCreated();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Image'] = this.image ? this.image.toJSON() : undefined;
        super.toJSON(data);
        return data;
    }
}
export class ImageCreationFailed extends ImageEventArgs {
    constructor(data) {
        super(data);
        this._discriminator = 'ImageCreationFailed';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.reason = _data['Reason'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ImageCreationFailed();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Reason'] = this.reason;
        super.toJSON(data);
        return data;
    }
}
export class ApiException extends Error {
    constructor(message, status, response, headers, result) {
        super();
        this.isApiException = true;
        this.message = message;
        this.status = status;
        this.response = response;
        this.headers = headers;
        this.result = result;
    }
    static isApiException(obj) {
        return obj.isApiException === true;
    }
}
export class LogList {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            if (Array.isArray(_data['Logs'])) {
                this.logs = [];
                for (const item of _data['Logs'])
                    this.logs.push(LogEntry.fromJS(item));
            }
            this.offset = _data['Offset'];
            this.filteredCount = _data['FilteredCount'];
            if (_data['TotalCount']) {
                this.totalCount = {};
                for (const key in _data['TotalCount']) {
                    if (Object.prototype.hasOwnProperty.call(_data['TotalCount'], key))
                        this.totalCount[key] = _data['TotalCount'][key];
                }
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new LogList();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.logs)) {
            data['Logs'] = [];
            for (const item of this.logs)
                data['Logs'].push(item.toJSON());
        }
        data['Offset'] = this.offset;
        data['FilteredCount'] = this.filteredCount;
        if (this.totalCount) {
            data['TotalCount'] = {};
            for (const key in this.totalCount) {
                if (Object.prototype.hasOwnProperty.call(this.totalCount, key))
                    data['TotalCount'][key] = this.totalCount[key];
            }
        }
        return data;
    }
}
export class LogEntry {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.source = _data['Source'];
            this.timestamp = _data['Timestamp'];
            this.message = _data['Message'];
            this.level = _data['Level'];
            this.durationNS = _data['DurationNS'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new LogEntry();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Source'] = this.source;
        data['Timestamp'] = this.timestamp;
        data['Message'] = this.message;
        data['Level'] = this.level;
        data['DurationNS'] = this.durationNS;
        return data;
    }
}
export class MissingLicenseResponse {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.message = _data['Message'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new MissingLicenseResponse();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Message'] = this.message;
        return data;
    }
}
export class RunStatus {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.sessionId = _data['SessionId'];
            this.verdict = _data['Verdict'];
            this.testPlanRunId = _data['TestPlanRunId'];
            this.failedToStart = _data['FailedToStart'];
            this.executionState = _data['ExecutionState'];
            if (Array.isArray(_data['ExecutingSteps'])) {
                this.executingSteps = [];
                for (const item of _data['ExecutingSteps'])
                    this.executingSteps.push(item);
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new RunStatus();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['SessionId'] = this.sessionId;
        data['Verdict'] = this.verdict;
        data['TestPlanRunId'] = this.testPlanRunId;
        data['FailedToStart'] = this.failedToStart;
        data['ExecutionState'] = this.executionState;
        if (Array.isArray(this.executingSteps)) {
            data['ExecutingSteps'] = [];
            for (const item of this.executingSteps)
                data['ExecutingSteps'].push(item);
        }
        return data;
    }
}
/** Enumeration containing the verdict types used for Verdict and Verdict properties. */
export var Verdict;
(function (Verdict) {
    Verdict["NotSet"] = "NotSet";
    Verdict["Pass"] = "Pass";
    Verdict["Inconclusive"] = "Inconclusive";
    Verdict["Fail"] = "Fail";
    Verdict["Aborted"] = "Aborted";
    Verdict["Error"] = "Error";
})(Verdict || (Verdict = {}));
export var ExecutionState;
(function (ExecutionState) {
    ExecutionState["Idle"] = "Idle";
    ExecutionState["Executing"] = "Executing";
    ExecutionState["Breaking"] = "Breaking";
    ExecutionState["Aborting"] = "Aborting";
    ExecutionState["WaitingForUserInput"] = "WaitingForUserInput";
})(ExecutionState || (ExecutionState = {}));
export class TestPlan {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            if (Array.isArray(_data['ChildTestSteps'])) {
                this.childTestSteps = [];
                for (const item of _data['ChildTestSteps'])
                    this.childTestSteps.push(TestStep.fromJS(item));
            }
            if (Array.isArray(_data['Settings'])) {
                this.settings = [];
                for (const item of _data['Settings'])
                    this.settings.push(Setting.fromJS(item));
            }
            this.isOpen = _data['IsOpen'];
            if (Array.isArray(_data['PropertiesToInclude'])) {
                this.propertiesToInclude = [];
                for (const item of _data['PropertiesToInclude'])
                    this.propertiesToInclude.push(item);
            }
            this.id = _data['Id'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new TestPlan();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.childTestSteps)) {
            data['ChildTestSteps'] = [];
            for (const item of this.childTestSteps)
                data['ChildTestSteps'].push(item.toJSON());
        }
        if (Array.isArray(this.settings)) {
            data['Settings'] = [];
            for (const item of this.settings)
                data['Settings'].push(item.toJSON());
        }
        data['IsOpen'] = this.isOpen;
        if (Array.isArray(this.propertiesToInclude)) {
            data['PropertiesToInclude'] = [];
            for (const item of this.propertiesToInclude)
                data['PropertiesToInclude'].push(item);
        }
        data['Id'] = this.id;
        return data;
    }
}
export class TestStep {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
        this._discriminator = 'TestStep';
    }
    init(_data) {
        if (_data) {
            this.id = _data['Id'];
            if (Array.isArray(_data['ChildTestSteps'])) {
                this.childTestSteps = [];
                for (const item of _data['ChildTestSteps'])
                    this.childTestSteps.push(TestStep.fromJS(item));
            }
            this.isChildTestStepsReadOnly = _data['IsChildTestStepsReadOnly'];
            this.isReadOnly = _data['IsReadOnly'];
            if (Array.isArray(_data['Settings'])) {
                this.settings = [];
                for (const item of _data['Settings'])
                    this.settings.push(Setting.fromJS(item));
            }
            this.typeName = _data['TypeName'];
            this.typeDisplay = _data['TypeDisplay'] ? DisplayAttribute.fromJS(_data['TypeDisplay']) : undefined;
            this.name = _data['Name'];
            this.expandedName = _data['ExpandedName'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        if (data['TestStepTypeOrInstance'] === 'TestStepType') {
            const result = new TestStepType();
            result.init(data);
            return result;
        }
        const result = new TestStep();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['TestStepTypeOrInstance'] = this._discriminator;
        data['Id'] = this.id;
        if (Array.isArray(this.childTestSteps)) {
            data['ChildTestSteps'] = [];
            for (const item of this.childTestSteps)
                data['ChildTestSteps'].push(item.toJSON());
        }
        data['IsChildTestStepsReadOnly'] = this.isChildTestStepsReadOnly;
        data['IsReadOnly'] = this.isReadOnly;
        if (Array.isArray(this.settings)) {
            data['Settings'] = [];
            for (const item of this.settings)
                data['Settings'].push(item.toJSON());
        }
        data['TypeName'] = this.typeName;
        data['TypeDisplay'] = this.typeDisplay ? this.typeDisplay.toJSON() : undefined;
        data['Name'] = this.name;
        data['ExpandedName'] = this.expandedName;
        return data;
    }
}
export class TestStepType extends TestStep {
    constructor(data) {
        super(data);
        this._discriminator = 'TestStepType';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            if (Array.isArray(_data['AvailableChildrenTypes'])) {
                this.availableChildrenTypes = [];
                for (const item of _data['AvailableChildrenTypes'])
                    this.availableChildrenTypes.push(item);
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new TestStepType();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.availableChildrenTypes)) {
            data['AvailableChildrenTypes'] = [];
            for (const item of this.availableChildrenTypes)
                data['AvailableChildrenTypes'].push(item);
        }
        super.toJSON(data);
        return data;
    }
}
export class TestStepCopy extends TestStep {
    constructor(data) {
        super(data);
        this._discriminator = 'TestStepCopy';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new TestStepCopy();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class TestStepValidationError {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.stepId = _data['StepId'];
            if (Array.isArray(_data['ValidationErrors'])) {
                this.validationErrors = [];
                for (const item of _data['ValidationErrors'])
                    this.validationErrors.push(ValidationError.fromJS(item));
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new TestStepValidationError();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['StepId'] = this.stepId;
        if (Array.isArray(this.validationErrors)) {
            data['ValidationErrors'] = [];
            for (const item of this.validationErrors)
                data['ValidationErrors'].push(item.toJSON());
        }
        return data;
    }
}
export class ValidationError {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.propertyName = _data['PropertyName'];
            this.error = _data['Error'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ValidationError();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['PropertyName'] = this.propertyName;
        data['Error'] = this.error;
        return data;
    }
}
export class CommonSettings {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.step = _data['Step'] ? TestStep.fromJS(_data['Step']) : undefined;
            if (Array.isArray(_data['StepIds'])) {
                this.stepIds = [];
                for (const item of _data['StepIds'])
                    this.stepIds.push(item);
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new CommonSettings();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Step'] = this.step ? this.step.toJSON() : undefined;
        if (Array.isArray(this.stepIds)) {
            data['StepIds'] = [];
            for (const item of this.stepIds)
                data['StepIds'].push(item);
        }
        return data;
    }
}
export class CommonContext {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            if (Array.isArray(_data['ContextItems'])) {
                this.contextItems = [];
                for (const item of _data['ContextItems'])
                    this.contextItems.push(Setting.fromJS(item));
            }
            if (Array.isArray(_data['StepIds'])) {
                this.stepIds = [];
                for (const item of _data['StepIds'])
                    this.stepIds.push(item);
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new CommonContext();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.contextItems)) {
            data['ContextItems'] = [];
            for (const item of this.contextItems)
                data['ContextItems'].push(item.toJSON());
        }
        if (Array.isArray(this.stepIds)) {
            data['StepIds'] = [];
            for (const item of this.stepIds)
                data['StepIds'].push(item);
        }
        return data;
    }
}
export class Interaction {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.timeout = _data['Timeout'];
            this.title = _data['Title'];
            this.modal = _data['Modal'];
            if (Array.isArray(_data['Settings'])) {
                this.settings = [];
                for (const item of _data['Settings'])
                    this.settings.push(Setting.fromJS(item));
            }
            this.id = _data['Id'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new Interaction();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Timeout'] = this.timeout;
        data['Title'] = this.title;
        data['Modal'] = this.modal;
        if (Array.isArray(this.settings)) {
            data['Settings'] = [];
            for (const item of this.settings)
                data['Settings'].push(item.toJSON());
        }
        data['Id'] = this.id;
        return data;
    }
}
export class InstalledFile {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.relativePath = _data['RelativePath'];
            this.tapPackage = _data['TapPackage'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new InstalledFile();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['RelativePath'] = this.relativePath;
        data['TapPackage'] = this.tapPackage;
        return data;
    }
}
export class BreakPoints {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            if (Array.isArray(_data['TestSteps'])) {
                this.testSteps = [];
                for (const item of _data['TestSteps'])
                    this.testSteps.push(item);
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new BreakPoints();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.testSteps)) {
            data['TestSteps'] = [];
            for (const item of this.testSteps)
                data['TestSteps'].push(item);
        }
        return data;
    }
}
export class Parameter {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.group = _data['Group'];
            this.name = _data['Name'];
            this.macroName = _data['MacroName'];
            this.parentLevel = _data['ParentLevel'];
            this.value = _data['Value'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new Parameter();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Group'] = this.group;
        data['Name'] = this.name;
        data['MacroName'] = this.macroName;
        data['ParentLevel'] = this.parentLevel;
        data['Value'] = this.value;
        return data;
    }
}
export class WatchDog {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.inactiveSeconds = _data['InactiveSeconds'];
            this.terminationTimeout = _data['TerminationTimeout'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new WatchDog();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['InactiveSeconds'] = this.inactiveSeconds;
        data['TerminationTimeout'] = this.terminationTimeout;
        return data;
    }
}
export class TestRun {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.status = _data['Status'];
            this.id = _data['Id'];
            this.verdict = _data['Verdict'];
            this.duration = _data['Duration'];
            if (Array.isArray(_data['Parameters'])) {
                this.parameters = [];
                for (const item of _data['Parameters'])
                    this.parameters.push(Parameter.fromJS(item));
            }
            this.testStepRun = _data['TestStepRun'] ? TestStepRun.fromJS(_data['TestStepRun']) : undefined;
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new TestRun();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Status'] = this.status;
        data['Id'] = this.id;
        data['Verdict'] = this.verdict;
        data['Duration'] = this.duration;
        if (Array.isArray(this.parameters)) {
            data['Parameters'] = [];
            for (const item of this.parameters)
                data['Parameters'].push(item.toJSON());
        }
        data['TestStepRun'] = this.testStepRun ? this.testStepRun.toJSON() : undefined;
        return data;
    }
}
export class TestStepRun {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.parentId = _data['ParentId'];
            this.testStepId = _data['TestStepId'];
            this.testStepName = _data['TestStepName'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new TestStepRun();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['ParentId'] = this.parentId;
        data['TestStepId'] = this.testStepId;
        data['TestStepName'] = this.testStepName;
        return data;
    }
}
export class LogEvent {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.source = _data['Source'];
            this.timestamp = _data['Timestamp'];
            this.message = _data['Message'];
            this.eventType = _data['EventType'];
            this.durationNS = _data['DurationNS'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new LogEvent();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Source'] = this.source;
        data['Timestamp'] = this.timestamp;
        data['Message'] = this.message;
        data['EventType'] = this.eventType;
        data['DurationNS'] = this.durationNS;
        return data;
    }
}
export class Result {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.stepRunID = _data['StepRunID'];
            this.status = _data['Status'];
            this.name = _data['Name'];
            this.rows = _data['Rows'];
            this.parent = _data['Parent'];
            if (Array.isArray(_data['Columns'])) {
                this.columns = [];
                for (const item of _data['Columns'])
                    this.columns.push(ResultColumn.fromJS(item));
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new Result();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['StepRunID'] = this.stepRunID;
        data['Status'] = this.status;
        data['Name'] = this.name;
        data['Rows'] = this.rows;
        data['Parent'] = this.parent;
        if (Array.isArray(this.columns)) {
            data['Columns'] = [];
            for (const item of this.columns)
                data['Columns'].push(item.toJSON());
        }
        return data;
    }
}
export class ResultColumn {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.name = _data['Name'];
            this.objectType = _data['ObjectType'];
            if (Array.isArray(_data['Data'])) {
                this.data = [];
                for (const item of _data['Data'])
                    this.data.push(item);
            }
            this.typeCode = _data['TypeCode'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new ResultColumn();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Name'] = this.name;
        data['ObjectType'] = this.objectType;
        if (Array.isArray(this.data)) {
            data['Data'] = [];
            for (const item of this.data)
                data['Data'].push(item);
        }
        data['TypeCode'] = this.typeCode;
        return data;
    }
}
export var SessionMetricKind;
(function (SessionMetricKind) {
    SessionMetricKind["Poll"] = "Poll";
    SessionMetricKind["Push"] = "Push";
    SessionMetricKind["PushPoll"] = "PushPoll";
})(SessionMetricKind || (SessionMetricKind = {}));
export var SessionMetricType;
(function (SessionMetricType) {
    SessionMetricType["Unknown"] = "Unknown";
    SessionMetricType["Double"] = "Double";
    SessionMetricType["Boolean"] = "Boolean";
    SessionMetricType["String"] = "String";
})(SessionMetricType || (SessionMetricType = {}));
export var MetricsPollRate;
(function (MetricsPollRate) {
    MetricsPollRate["OneSecond"] = "OneSecond";
    MetricsPollRate["TwoSeconds"] = "TwoSeconds";
    MetricsPollRate["FiveSeconds"] = "FiveSeconds";
    MetricsPollRate["TenSeconds"] = "TenSeconds";
    MetricsPollRate["FifteenSeconds"] = "FifteenSeconds";
    MetricsPollRate["OneMinute"] = "OneMinute";
    MetricsPollRate["TwoMinutes"] = "TwoMinutes";
    MetricsPollRate["FiveMinutes"] = "FiveMinutes";
    MetricsPollRate["TenMinutes"] = "TenMinutes";
    MetricsPollRate["FifteenMinutes"] = "FifteenMinutes";
    MetricsPollRate["OneHour"] = "OneHour";
})(MetricsPollRate || (MetricsPollRate = {}));
export class SessionMetricInfo {
    constructor(data) {
        this.attributes = [];
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.publish = _data['Publish'];
            this.kind = _data['Kind'];
            this.type = _data['Type'];
            this.groupName = _data['GroupName'];
            this.name = _data['Name'];
            this.metricFullName = _data['MetricFullName'];
            this.subjectPostfix = _data['SubjectPostfix'];
            if (Array.isArray(_data['Attributes']))
                this.attributes = _data['Attributes'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new SessionMetricInfo();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Publish'] = this.publish;
        data['Kind'] = this.kind;
        data['Type'] = this.type;
        data['GroupName'] = this.groupName;
        data['Name'] = this.name;
        data['MetricFullName'] = this.metricFullName;
        data['SubjectPostfix'] = this.subjectPostfix;
        data['Attributes'] = [];
        if (Array.isArray(this.attributes)) {
            data['Attributes'] = this.attributes;
        }
        return data;
    }
}
export class MetricsConfiguration {
    constructor(data) {
        this.metrics = [];
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.publishRate = _data['PublishRate'];
            if (Array.isArray(_data['Metrics']))
                this.metrics = _data['Metrics'].map(item => SessionMetricInfo.fromJS(item));
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new MetricsConfiguration();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['PublishRate'] = this.publishRate;
        if (Array.isArray(this.metrics)) {
            data['Metrics'] = this.metrics.map(item => item.toJSON());
        }
        return data;
    }
}
export class MetricValue {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.time = _data['Time'];
            this.value = _data['Value'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new MetricValue();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Time'] = this.time;
        data['Value'] = this.value;
        return data;
    }
}
export class SessionEvent {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
        this._discriminator = 'SessionEvent';
    }
    init(_data) {
        if (_data) {
            this.eventType = _data['EventType'];
            this.sessionId = _data['SessionId'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        if (data['discriminator'] === 'SessionTimeoutEventArgs') {
            const result = new SessionTimeoutEventArgs();
            result.init(data);
            return result;
        }
        if (data['discriminator'] === 'StartingEventArgs') {
            const result = new StartingEventArgs();
            result.init(data);
            return result;
        }
        if (data['discriminator'] === 'StartedEventArgs') {
            const result = new StartedEventArgs();
            result.init(data);
            return result;
        }
        if (data['discriminator'] === 'StoppingEventArgs') {
            const result = new StoppingEventArgs();
            result.init(data);
            return result;
        }
        if (data['discriminator'] === 'StoppedEventArgs') {
            const result = new StoppedEventArgs();
            result.init(data);
            return result;
        }
        if (data['discriminator'] === 'TestPlanChangeEventArgs') {
            const result = new TestPlanChangeEventArgs();
            result.init(data);
            return result;
        }
        if (data['discriminator'] === 'TestPlanExecutionStateChangedEventArgs') {
            const result = new TestPlanExecutionStateChangedEventArgs();
            result.init(data);
            return result;
        }
        if (data['discriminator'] === 'SettingsChangedEventArgs') {
            const result = new SettingsChangedEventArgs();
            result.init(data);
            return result;
        }
        if (data['discriminator'] === 'TestStepChangeEventArgs') {
            const result = new TestStepChangeEventArgs();
            result.init(data);
            return result;
        }
        if (data['discriminator'] === 'BreakEventArgs') {
            const result = new BreakEventArgs();
            result.init(data);
            return result;
        }
        if (data['discriminator'] === 'UserInputRequestEventArgs') {
            const result = new UserInputRequestEventArgs();
            result.init(data);
            return result;
        }
        if (data['discriminator'] === 'UserInputRequestCompletedEventArgs') {
            const result = new UserInputRequestCompletedEventArgs();
            result.init(data);
            return result;
        }
        if (data['discriminator'] === 'TestPlanSettingsChangedEventArgs') {
            const result = new TestPlanSettingsChangedEventArgs();
            result.init(data);
            return result;
        }
        const result = new SessionEvent();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['discriminator'] = this._discriminator;
        data['EventType'] = this.eventType;
        data['SessionId'] = this.sessionId;
        return data;
    }
}
export var SessionEventType;
(function (SessionEventType) {
    SessionEventType["SessionStarting"] = "SessionStarting";
    SessionEventType["SessionStarted"] = "SessionStarted";
    SessionEventType["SessionStopping"] = "SessionStopping";
    SessionEventType["SessionStopped"] = "SessionStopped";
    SessionEventType["TestPlanChanged"] = "TestPlanChanged";
    SessionEventType["TestPlanExecutionStateChanged"] = "TestPlanExecutionStateChanged";
    SessionEventType["SettingsChanged"] = "SettingsChanged";
    SessionEventType["TestStepChanged"] = "TestStepChanged";
    SessionEventType["BreakEvent"] = "BreakEvent";
    SessionEventType["UserInputRequested"] = "UserInputRequested";
    SessionEventType["UserInputCompleted"] = "UserInputCompleted";
    SessionEventType["SessionTimeoutHit"] = "SessionTimeoutHit";
    SessionEventType["TestPlanSettingsChanged"] = "TestPlanSettingsChanged";
    SessionEventType["TypeCacheInvalidated"] = "TypeCacheInvalidated";
    SessionEventType["Heartbeat"] = "Heartbeat";
    SessionEventType["MetricsConfigurationChanged"] = "MetricsConfigurationChanged";
})(SessionEventType || (SessionEventType = {}));
export class SessionTimeoutEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'SessionTimeoutEventArgs';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new SessionTimeoutEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class StartingEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'StartingEventArgs';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new StartingEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class StartedEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'StartedEventArgs';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new StartedEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class StoppingEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'StoppingEventArgs';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new StoppingEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class StoppedEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'StoppedEventArgs';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new StoppedEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class TestPlanChangeEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'TestPlanChangeEventArgs';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new TestPlanChangeEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class TestPlanExecutionStateChangedEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'TestPlanExecutionStateChangedEventArgs';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.runStatus = _data['RunStatus'] ? RunStatus.fromJS(_data['RunStatus']) : undefined;
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new TestPlanExecutionStateChangedEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['RunStatus'] = this.runStatus ? this.runStatus.toJSON() : undefined;
        super.toJSON(data);
        return data;
    }
}
export class SettingsChangedEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'SettingsChangedEventArgs';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new SettingsChangedEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class TestStepChangeEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'TestStepChangeEventArgs';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.stepId = _data['StepId'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new TestStepChangeEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['StepId'] = this.stepId;
        super.toJSON(data);
        return data;
    }
}
export class BreakEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'BreakEventArgs';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.stepId = _data['StepId'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new BreakEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['StepId'] = this.stepId;
        super.toJSON(data);
        return data;
    }
}
export class UserInputRequestEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'UserInputRequestEventArgs';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.requestId = _data['RequestId'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new UserInputRequestEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['RequestId'] = this.requestId;
        super.toJSON(data);
        return data;
    }
}
export class UserInputRequestCompletedEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'UserInputRequestCompletedEventArgs';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.requestId = _data['RequestId'];
            this.answered = _data['Answered'];
            this.timeout = _data['Timeout'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new UserInputRequestCompletedEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['RequestId'] = this.requestId;
        data['Answered'] = this.answered;
        data['Timeout'] = this.timeout;
        super.toJSON(data);
        return data;
    }
}
export class TestPlanSettingsChangedEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'TestPlanSettingsChangedEventArgs';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new TestPlanSettingsChangedEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class HeartbeatEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'HeartbeatEventArgs';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new HeartbeatEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class MetricsConfigurationChangedEventArgs extends SessionEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'MetricsConfigurationChangedEventArgs';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new MetricsConfigurationChangedEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class OnTestPlanRun {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.status = _data['Status'];
            this.userId = _data['UserId'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new OnTestPlanRun();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Status'] = this.status;
        data['UserId'] = this.userId;
        return data;
    }
}
export class OnTestStepRun {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.status = _data['Status'];
            this.stepId = _data['StepId'];
            this.parentRunId = _data['ParentRunId'];
            this.verdict = _data['Verdict'];
            this.duration = _data['Duration'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new OnTestStepRun();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Status'] = this.status;
        data['StepId'] = this.stepId;
        data['ParentRunId'] = this.parentRunId;
        data['Verdict'] = this.verdict;
        data['Duration'] = this.duration;
        return data;
    }
}
export class TestStepRunEvent {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
        this._discriminator = 'TestStepRunEvent';
    }
    init(_data) {
        if (_data) {
            this.parent = _data['Parent'];
            this.testStepId = _data['TestStepId'];
            this.testStepName = _data['TestStepName'];
            this.testStepTypeName = _data['TestStepTypeName'];
            this.id = _data['Id'];
            this.verdict = _data['Verdict'];
            this.startTime = _data['StartTime'];
            if (Array.isArray(_data['Parameters'])) {
                this.parameters = [];
                for (const item of _data['Parameters'])
                    this.parameters.push(Parameter.fromJS(item));
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        if (data['discriminator'] === 'TestStepRunStartEventArgs') {
            const result = new TestStepRunStartEventArgs();
            result.init(data);
            return result;
        }
        if (data['discriminator'] === 'TestStepRunCompletedEventArgs') {
            const result = new TestStepRunCompletedEventArgs();
            result.init(data);
            return result;
        }
        const result = new TestStepRunEvent();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data['Parent'] = this.parent;
        data['TestStepId'] = this.testStepId;
        data['TestStepName'] = this.testStepName;
        data['TestStepTypeName'] = this.testStepTypeName;
        data['Id'] = this.id;
        data['Verdict'] = this.verdict;
        data['StartTime'] = this.startTime;
        if (Array.isArray(this.parameters)) {
            data['Parameters'] = [];
            for (const item of this.parameters)
                data['Parameters'].push(item.toJSON());
        }
        return data;
    }
}
export class TestStepRunStartEventArgs extends TestStepRunEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'TestStepRunStartEventArgs';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new TestStepRunStartEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class TestStepRunCompletedEventArgs extends TestStepRunEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'TestStepRunCompletedEventArgs';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new TestStepRunCompletedEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class TestPlanRunEvent {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
        this._discriminator = 'TestPlanRunEvent';
    }
    init(_data) {
        if (_data) {
            this.testPlanRunId = _data['Run/TestPlanRunId'];
            this.testPlanRunGuid = _data['Run/TestPlanRunGuid'];
            this.path = _data['Run/Path'];
            this.name = _data['Run/Name'];
            this.verdict = _data['Run/Verdict'];
            this.startTime = _data['Run/StartTime'];
            this.runner = _data['Run/Runner'];
            this.status = _data['Run/Status'];
            this.isCampaign = _data['Run/IsCampaign'];
            this.operator = _data['Run/Operator'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        if (data['discriminator'] === 'TestPlanRunStartEventArgs') {
            const result = new TestPlanRunStartEventArgs();
            result.init(data);
            return result;
        }
        if (data['discriminator'] === 'TestPlanRunCompletedEventArgs') {
            const result = new TestPlanRunCompletedEventArgs();
            result.init(data);
            return result;
        }
        const result = new TestPlanRunEvent();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Run/TestPlanRunId'] = this.testPlanRunId;
        data['Run/TestPlanRunGuid'] = this.testPlanRunGuid;
        data['Run/Path'] = this.path;
        data['Run/Name'] = this.name;
        data['Run/Verdict'] = this.verdict;
        data['Run/StartTime'] = this.startTime;
        data['Run/Runner'] = this.runner;
        data['Run/Status'] = this.status;
        data['Run/IsCampaign'] = this.isCampaign;
        data['Run/Operator'] = this.operator;
        return data;
    }
}
export class TestPlanRunStartEventArgs extends TestPlanRunEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'TestPlanRunStartEventArgs';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new TestPlanRunStartEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class TestPlanRunCompletedEventArgs extends TestPlanRunEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'TestPlanRunCompletedEventArgs';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            this.durationInSeconds = _data['Run/DurationInSeconds'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new TestPlanRunCompletedEventArgs();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['Run/DurationInSeconds'] = this.durationInSeconds;
        super.toJSON(data);
        return data;
    }
}
export class RunnerEvent {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
        this.type = 'RunnerEvent';
    }
    init(_data) {
        if (_data) {
            this.runnerId = _data['RunnerId'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        if (data['type'] === 'RunnerRegisteredEvent') {
            const result = new RunnerRegisteredEvent();
            result.init(data);
            return result;
        }
        if (data['type'] === 'RunnerUpdatedEvent') {
            const result = new RunnerUpdatedEvent();
            result.init(data);
            return result;
        }
        if (data['type'] === 'RunnerDeletedEvent') {
            const result = new RunnerDeletedEvent();
            result.init(data);
            return result;
        }
        const result = new RunnerEvent();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['RunnerId'] = this.runnerId;
        return data;
    }
}
export class RunnerRegisteredEvent extends RunnerEvent {
    constructor(data) {
        super(data);
        this.type = 'RunnerRegisteredEvent';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new RunnerRegisteredEvent();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class RunnerUpdatedEvent extends RunnerEvent {
    constructor(data) {
        super(data);
        this.type = 'RunnerUpdatedEvent';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new RunnerUpdatedEvent();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class RunnerDeletedEvent extends RunnerEvent {
    constructor(data) {
        super(data);
        this.type = 'RunnerDeletedEvent';
    }
    init(_data) {
        super.init(_data);
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new RunnerDeletedEvent();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        super.toJSON(data);
        return data;
    }
}
export class MetadataUpdatedEvent {
    constructor(data) {
        if (data) {
            for (const property in data) {
                if (Object.prototype.hasOwnProperty.call(data, property))
                    this[property] = data[property];
            }
        }
    }
    init(_data) {
        if (_data) {
            this.sessionId = _data['SessionId'];
            this.metadata = _data['Metadata'];
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new MetadataUpdatedEvent();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        data['SessionId'] = this.sessionId;
        data['Metadata'] = this.metadata;
        return data;
    }
}
export class AssetUpdatedEvent extends RunnerEvent {
    constructor(data) {
        super(data);
        this._discriminator = 'AssetUpdatedEvent';
    }
    init(_data) {
        super.init(_data);
        if (_data) {
            if (Array.isArray(_data['Assets'])) {
                this.assets = [];
                for (const item of _data['Assets'])
                    this.assets.push(item);
            }
        }
    }
    static fromJS(data) {
        data = typeof data === 'object' ? data : {};
        const result = new AssetUpdatedEvent();
        result.init(data);
        return result;
    }
    toJSON(data) {
        data = typeof data === 'object' ? data : {};
        if (Array.isArray(this.assets)) {
            data['Assets'] = [];
            for (const item of this.assets)
                data['Assets'].push(item);
        }
        super.toJSON(data);
        return data;
    }
}
